==> mx-repo-manager_21.8.tar.xz: mx-repo-manager-21.8/translations/mx-repo-manager_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="66"/>
        <source>MX Repo Manager</source>
        <translation>MX Pakketbronbeheer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Selecteer de APT pakketbron die u wilt gebruiken:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX pakketbronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Selecteer de snelste MX pakketbron voor me</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>search</source>
        <translation>zoeken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Debian repos</source>
        <translation>Debian pakketbronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Selecteer de snelste Debian pakketbron voor me</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Individual sources</source>
        <translation>Individuele bronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Restore original APT sources</source>
        <translation>Herstel originele APT bronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>Please wait...</source>
        <translation>Even wachten aub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="394"/>
        <location filename="../mainwindow.cpp" line="677"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="394"/>
        <location filename="../mainwindow.cpp" line="679"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Uw nieuwe selectie zal de volgende keer dat de bronnen geupdate worden effectief worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Lists</source>
        <translation>Lijsten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Bronnen (aangevinkte bronnen zijn ingeschakeld)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <location filename="../mainwindow.cpp" line="596"/>
        <location filename="../mainwindow.cpp" line="614"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="641"/>
        <location filename="../mainwindow.cpp" line="658"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Could not change the repo.</source>
        <translation>Kon de pakketbron niet wijzigen.</translation>
    </message>
    <message>
        <source>About MX Repo Manager</source>
        <translation type="vanished">Over MX Pakketbronbeheer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programma om de standaard APT pakketbron te kiezen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licentie</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Close</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Je hebt de MX Test Pakketbron geselecteerd. Het is niet aan te raden om deze ingeschakeld te laten of alle pakketten eruit te upgraden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Een veiliger optie is om pakketten individueel te installeren met MX Pakket Installeerder.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Selecteer de APT pakketbron en bronnen die u wilt gebruiken:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt kon de snelste pakketbron niet ontdekken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Could not detect fastest repo.</source>
        <translation>Kon de snelste pakketbron niet ontdekken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>MX version not detected or out of range: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="658"/>
        <source>Could not download original APT files.</source>
        <translation>Kon de originele APT bestanden niet downloaden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>Could not unzip downloaded file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>Enabling AHS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Originele APT bronnen zijn teruggezet naar de release status. Bronbestanden die door de gebruiker zijn toegevoegd in /etc/apt/sources.list.d/ zijn niet gewijzigd.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">U dient deze toepassing als &apos;root&apos; uit te voeren.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Close</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Error</source>
        <translation type="unfinished">Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-repo-manager_23.9.tar.xz: mx-repo-manager-23.9/translations/mx-repo-manager_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Repo Manager</source>
        <translation>MX Pakketbronbeheer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Selecteer de APT pakketbron die u wilt gebruiken:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX pakketbronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Selecteer de snelste MX pakketbron voor me</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>zoeken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian pakketbronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Selecteer de snelste Debian pakketbron voor me</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Individuele bronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Herstel originele APT bronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="467"/>
        <location filename="../mainwindow.cpp" line="764"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="163"/>
        <location filename="../mainwindow.cpp" line="467"/>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Uw nieuwe selectie zal de volgende keer dat de bronnen geupdate worden effectief worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Lists</source>
        <translation>Lijsten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Bronnen (aangevinkte bronnen zijn ingeschakeld)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <location filename="../mainwindow.cpp" line="673"/>
        <location filename="../mainwindow.cpp" line="683"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <location filename="../mainwindow.cpp" line="715"/>
        <location filename="../mainwindow.cpp" line="723"/>
        <location filename="../mainwindow.cpp" line="740"/>
        <location filename="../mainwindow.cpp" line="746"/>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Could not change the repo.</source>
        <translation>Kon de pakketbron niet wijzigen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Please wait...</source>
        <translation>Even wachten aub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programma om de standaard APT pakketbron te kiezen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Je hebt de MX Test Pakketbron geselecteerd. Het is niet aan te raden om deze ingeschakeld te laten of alle pakketten eruit te upgraden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Een veiliger optie is om pakketten individueel te installeren met MX Pakket Installeerder.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Selecteer de APT pakketbron en bronnen die u wilt gebruiken:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt kon de snelste pakketbron niet ontdekken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <source>Could not detect fastest repo.</source>
        <translation>Kon de snelste pakketbron niet ontdekken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="715"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <source>MX version not detected or out of range: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="740"/>
        <source>Could not download original APT files.</source>
        <translation>Kon de originele APT bestanden niet downloaden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="746"/>
        <source>Could not unzip downloaded file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="757"/>
        <source>Enabling AHS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="757"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Originele APT bronnen zijn teruggezet naar de release status. Bronbestanden die door de gebruiker zijn toegevoegd in /etc/apt/sources.list.d/ zijn niet gewijzigd.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Er is een fout opgetreden bij het schrijven van bestand: %1. Controleer of u voldoende vrije ruimte op uw schijf heeft</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
</context>
</TS>
